@@ -3,7 +3,7 @@ package HTML::FormBuilder::Field;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 use Scalar::Util qw(weaken blessed);
@@ -221,9 +221,11 @@ HTML::FormBuilder::Field - Field container used by HTML::FormBuilder
 
     my $form = HTML::FormBuilder->new(data => {id => 'testform});
 
-    my $fieldset_index = $form->add_fieldset({id => 'fieldset1'});
+    my $fieldset = $form->add_fieldset({id => 'fieldset1'});
 
-    $form->add_field(fieldset_index, {input => {type => 'text', value => 'Join'}});
+    $fieldset->add_field({input => {type => 'text', value => 'Join'}});
+
+    $form->add_field($fieldset_index, {input => {type => 'text', value => 'Join'}});
 
 =head1 AUTHOR
 
